Config class

@create at 2021/7/15 15:01 @create by kevin @desc 参数类型配置

Constructors

Config({DataType dataType = DataType.DataMap, String parentId = 'parentId', String value = 'value', String label = 'label', String id = 'id', String children = 'children', TreeLineStyle lineStyle = const TreeLineStyle()})
const

Properties

children → String
final
dataType → DataType
数据类型
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
label → String
final
lineStyle → TreeLineStyle
树形连接线样式
final
parentId → String
父级id key
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
value key
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited