FlutterTreePro class

@create at 2021/7/15 15:01 @create by kevin @desc components

Inheritance

Constructors

FlutterTreePro({Key? key, List<Map<String, dynamic>> treeData = const <Map<String, dynamic>>[], Map<String, dynamic> initialTreeData = const <String, dynamic>{}, Config config = const Config(), List<Map<String, dynamic>> listData = const <Map<String, dynamic>>[], List<Map<String, dynamic>> initialListData = const <Map<String, dynamic>>[], required dynamic onChecked(List<Map<String, dynamic>>), bool isExpanded = false, bool isRTL = false, bool isSingleSelect = false, int initialSelectValue = 0})

Properties

config → Config
Config
final
hashCode → int
The hash code for this object.
no setterinherited
initialListData → List<Map<String, dynamic>>
initial source data type List
final
initialSelectValue → int
initial select value
final
initialTreeData → Map<String, dynamic>
initial source data type Map
final
isExpanded → bool
if expanded items
final
isRTL → bool
is right to left
final
isSingleSelect → bool
is single select
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
listData → List<Map<String, dynamic>>
source data type List
final
onChecked → dynamic Function(List<Map<String, dynamic>>)
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
treeData → List<Map<String, dynamic>>
source data type Map
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _FlutterTreeProState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited