TreeLineStyle class

树形连接线样式

Constructors

TreeLineStyle({Color color = const Color(0xFFD9D9D9), double width = 1.0, double indent = 24.0, bool showVerticalLine = true, bool showHorizontalLine = true})
const

Properties

color Color
线条颜色
final
hashCode int
The hash code for this object.
no setterinherited
indent double
缩进宽度(每一级的间距)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showHorizontalLine bool
是否显示水平连接线
final
showVerticalLine bool
是否显示竖线
final
width double
线条宽度
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited